// eslint-disable-next-line no-new-func
var globalThis = new Function('return this')()
var FileReader = globalThis.FileReader,
  Promise = globalThis.Promise

function promisify(method) {
  return function(blob, encoding) {
    return new Promise(function(resolve, reject) {
      var fileReader = new FileReader()

      fileReader.onload = function() {
        return resolve(fileReader.result)
      }

      fileReader.onerror = function() {
        return reject(fileReader.error)
      }

      method.call(fileReader, blob, encoding)
    })
  }
}

var readAsArrayBuffer = FileReader.prototype.readAsArrayBuffer
var arrayBuffer = promisify(readAsArrayBuffer)

var fromCharCode = String.fromCharCode

function arrayBufferToBinaryString(buffer) {
  var bytes = new Uint8Array(buffer)
  var byteLength = bytes.byteLength
  var binary = '' // can we use a chuck size for this loop?

  for (var i = 0; i < byteLength; i += 1) {
    binary += fromCharCode(bytes[i])
  }

  return binary
}

var readAsBinaryString = FileReader.prototype.readAsBinaryString

function getBinaryStringFromArrayBuffer(blob) {
  return arrayBuffer(blob).then(arrayBufferToBinaryString)
} // IE 10 don't has `readAsBinaryString`

var binaryString = readAsBinaryString
  ? promisify(readAsBinaryString)
  : getBinaryStringFromArrayBuffer

var readAsDataURL = FileReader.prototype.readAsDataURL
var dataURL = promisify(readAsDataURL)

var readAsText = FileReader.prototype.readAsText
var text = promisify(readAsText)

// eslint-disable-next-line unicorn/import-index

var FileReader$1 = function FileReader() {}

var prototype = FileReader$1.prototype
prototype.readAsArrayBuffer = arrayBuffer
prototype.readAsBinaryString = binaryString
prototype.readAsDataURL = dataURL
prototype.readAsText = text
FileReader$1.readAsArrayBuffer = arrayBuffer
FileReader$1.readAsBinaryString = binaryString
FileReader$1.readAsDataURL = dataURL
FileReader$1.readAsText = text
FileReader$1.arrayBuffer = arrayBuffer
FileReader$1.binaryString = binaryString
FileReader$1.dataURL = dataURL
FileReader$1.text = text

export default FileReader$1
export {
  arrayBuffer,
  binaryString,
  dataURL,
  arrayBuffer as readAsArrayBuffer,
  binaryString as readAsBinaryString,
  dataURL as readAsDataURL,
  text as readAsText,
  text,
}
//# sourceMappingURL=index.mjs.map
